@@ -1,4 +1,4 @@
-/* $Id$ */
+/* $Id: loadavg.h,v 1.11 1998/10/11 18:13:59 martin Exp $ */
 
 /* Copyright (C) 1995, 1996, 1997 Free Software Foundation, Inc.
    This file is part of the Gnome Top Library.
@@ -63,25 +63,6 @@ extern void glibtop_init_loadavg_s __P((glibtop *));
 extern void glibtop_get_loadavg_s __P((glibtop *, glibtop_loadavg *));
 #endif
 
-#ifdef GLIBTOP_GUILE
-
-/* You need to link with -lgtop_guile to get this stuff here. */
-
-extern SCM glibtop_guile_get_loadavg __P((void));
-
-#endif
-
-#ifdef GLIBTOP_GUILE_NAMES
-
-/* You need to link with -lgtop_guile_names to get this stuff here. */
-
-extern SCM glibtop_guile_names_loadavg __P((void));
-extern SCM glibtop_guile_types_loadavg __P((void));
-extern SCM glibtop_guile_labels_loadavg __P((void));
-extern SCM glibtop_guile_descriptions_loadavg __P((void));
-
-#endif
-
 #ifdef GLIBTOP_NAMES
 
 /* You need to link with -lgtop_names to get this stuff here. */
