@@ -41,7 +41,6 @@
 
 #include <glibtop/gnuserv.h>
 
-#include <gnome-argp.h>
 #include <popt-gnome.h>
 
 #include "daemon.h"
@@ -50,6 +49,14 @@
 #include <sys/select.h>
 #endif
 
+#ifndef HAVE_PROGRAM_INVOCATION_SHORT_NAME
+char *program_invocation_short_name;
+#endif
+
+#ifndef HAVE_PROGRAM_INVOCATION_NAME
+char *program_invocation_name;
+#endif
+
 extern void handle_parent_connection __P ((int));
 extern void handle_slave_connection __P ((int, int));
 extern void handle_ipc_connection __P ((int));
