@@ -1,4 +1,4 @@
-/* $Id: mem.c,v 1.6 1998/08/24 19:55:24 martin Exp $ */
+/* $Id: mem.c,v 1.11 1998/12/06 17:02:45 martin Exp $ */
 
 /* Copyright (C) 1995, 1996, 1997 Free Software Foundation, Inc.
    This file is part of the Gnome Top Library.
@@ -32,8 +32,11 @@
 static const unsigned long _glibtop_sysdeps_mem =
 (1 << GLIBTOP_MEM_TOTAL) + (1 << GLIBTOP_MEM_USED) +
 (1 << GLIBTOP_MEM_FREE) + (1 << GLIBTOP_MEM_SHARED) +
-(1 << GLIBTOP_MEM_BUFFER) + (1 << GLIBTOP_MEM_CACHED) +
-(1 << GLIBTOP_MEM_USER);
+(1 << GLIBTOP_MEM_BUFFER) +
+#ifdef __FreeBSD__
+(1 << GLIBTOP_MEM_CACHED) +
+#endif
+(1 << GLIBTOP_MEM_USER) + (1 << GLIBTOP_MEM_LOCKED);
 
 #ifndef LOG1024
 #define LOG1024		10
@@ -48,12 +51,16 @@ static int pageshift;		/* log base 2 of the pagesize */
 /* nlist structure for kernel access */
 static struct nlist nlst [] = {
 	{ "_cnt" },
+#ifdef __FreeBSD__
 	{ "_bufspace" },
+#else
+	{ "_bufpages" },
+#endif
 	{ 0 }
 };
 
 /* MIB array for sysctl */
-static int mib_length=2;
+/* static int mib_length=2; */
 static int mib [] = { CTL_VM, VM_METER };
 
 /* Init function. */
@@ -63,10 +70,10 @@ glibtop_init_mem_p (glibtop *server)
 {
 	register int pagesize;
 
-	server->sysdeps.mem = _glibtop_sysdeps_mem;
-
-	if (kvm_nlist (server->machine.kd, nlst) != 0)
-		glibtop_error_io_r (server, "kvm_nlist");
+	if (kvm_nlist (server->machine.kd, nlst) != 0) {
+		glibtop_warn_io_r (server, "kvm_nlist (mem)");
+		return;
+	}
 
 	/* get the page size with "getpagesize" and calculate pageshift
 	 * from it */
@@ -79,6 +86,8 @@ glibtop_init_mem_p (glibtop *server)
 
 	/* we only need the amount of log(2)1024 for our conversion */
 	pageshift -= LOG1024;
+
+	server->sysdeps.mem = _glibtop_sysdeps_mem;
 }
 
 void
@@ -87,56 +96,73 @@ glibtop_get_mem_p (glibtop *server, glibtop_mem *buf)
 	struct vmtotal vmt;
 	size_t length_vmt;
 	struct vmmeter vmm;
+	u_int v_used_count;
+	u_int v_total_count;
 	int bufspace;
 
 	glibtop_init_p (server, (1 << GLIBTOP_SYSDEPS_MEM), 0);
 	
 	memset (buf, 0, sizeof (glibtop_mem));
 
+	if (server->sysdeps.mem == 0)
+		return;
+
 	/* [FIXME: On FreeBSD 2.2.6, sysctl () returns an incorrect
 	 *         value for `vmt.vm'. We use some code from Unix top
 	 *         here.] */
 
 	/* Get the data from sysctl */
 	length_vmt = sizeof (vmt);
-	if (sysctl (mib, 2, &vmt, &length_vmt, NULL, 0))
-		glibtop_error_io_r (server, "sysctl");
+	if (sysctl (mib, 2, &vmt, &length_vmt, NULL, 0)) {
+		glibtop_warn_io_r (server, "sysctl");
+		return;
+	}
 	
 	/* Get the data from kvm_* */
 	if (kvm_read (server->machine.kd, nlst[0].n_value,
-		      &vmm, sizeof (vmm)) != sizeof (vmm))
-		glibtop_error_io_r (server, "kvm_read (cnt)");
+		      &vmm, sizeof (vmm)) != sizeof (vmm)) {
+		glibtop_warn_io_r (server, "kvm_read (cnt)");
+		return;
+	}
 
 	if (kvm_read (server->machine.kd, nlst[1].n_value,
-		      &bufspace, sizeof (bufspace)) != sizeof (bufspace))
-		glibtop_error_io_r (server, "kvm_read (bufspace)");
+		      &bufspace, sizeof (bufspace)) != sizeof (bufspace)) {
+		glibtop_warn_io_r (server, "kvm_read (bufspace)");
+		return;
+	}
   
-	/* Set the values to return */
-	buf->flags = _glibtop_sysdeps_mem;
-
 	/* convert memory stats to Kbytes */
 
-	buf->total = (u_int64_t) pagetok (vmm.v_page_count) << LOG1024;
-	buf->used = (u_int64_t) pagetok (vmm.v_active_count) << LOG1024;
-	buf->free = (u_int64_t) pagetok (vmm.v_free_count) << LOG1024;
+#ifdef __FreeBSD__
+	v_total_count = vmm.v_page_count;
+#else
+	v_total_count = vmm.v_kernel_pages +
+		vmm.v_free_count + vmm.v_wire_count +
+		vmm.v_active_count + vmm.v_inactive_count;
+#endif
 
+	v_used_count = vmm.v_active_count + vmm.v_inactive_count;
+
+	buf->total = (u_int64_t) pagetok (v_total_count) << LOG1024;
+	buf->used  = (u_int64_t) pagetok (v_used_count) << LOG1024;
+	buf->free  = (u_int64_t) pagetok (vmm.v_free_count) << LOG1024;
+
+#ifdef __FreeBSD__
 	buf->cached = (u_int64_t) pagetok (vmm.v_cache_count) << LOG1024;
-	buf->shared = (u_int64_t) pagetok (vmt.t_vmshr) << LOG1024;
+#endif
 
+	buf->locked = (u_int64_t) pagetok (vmm.v_wire_count) << LOG1024;
+	buf->shared = (u_int64_t) pagetok (vmt.t_rmshr) << LOG1024;
+
+#if __FreeBSD__
 	buf->buffer = (u_int64_t) bufspace;
-
-#if 0
-        if (swappgsin < 0) {
-	    memory_stats[5] = 0;
-	    memory_stats[6] = 0;
-	} else {
-	    memory_stats[5] = pagetok(((vmm.v_swappgsin - swappgsin)));
-	    memory_stats[6] = pagetok(((vmm.v_swappgsout - swappgsout)));
-	}
-        swappgsin = vmm.v_swappgsin;
-	swappgsout = vmm.v_swappgsout;
+#else
+	buf->buffer = (u_int64_t) pagetok (bufspace) << LOG1024;
 #endif
 
 	/* user */
 	buf->user = buf->total - buf->free - buf->shared - buf->buffer;
+
+	/* Set the values to return */
+	buf->flags = _glibtop_sysdeps_mem;
 }
