@@ -1,4 +1,4 @@
-/* $Id: msg_limits.c,v 1.5 1998/08/24 19:55:25 martin Exp $ */
+/* $Id: msg_limits.c,v 1.7 1998/12/05 18:52:00 martin Exp $ */
 
 /* Copyright (C) 1995, 1996, 1997 Free Software Foundation, Inc.
    This file is part of the Gnome Top Library.
@@ -27,7 +27,11 @@
 
 /* #define KERNEL to get declaration of `struct msginfo'. */
 
-#define KERNEL
+#ifdef __FreeBSD__
+#define KERNEL 1
+#else
+#define _KERNEL 1
+#endif
 
 #include <sys/ipc.h>
 #include <sys/msg.h>
@@ -53,14 +57,18 @@ static struct nlist nlst [] = {
 void
 glibtop_init_msg_limits_p (glibtop *server)
 {
-	server->sysdeps.msg_limits = _glibtop_sysdeps_msg_limits;
-
-	if (kvm_nlist (server->machine.kd, nlst) != 0)
-		glibtop_error_io_r (server, "kvm_nlist");
+	if (kvm_nlist (server->machine.kd, nlst) != 0) {
+		glibtop_warn_io_r (server, "kvm_nlist (msg_limits)");
+		return;
+	}
 	
 	if (kvm_read (server->machine.kd, nlst [0].n_value,
-		      &_msginfo, sizeof (_msginfo)) != sizeof (_msginfo))
-		glibtop_error_io_r (server, "kvm_read (msginfo)");
+		      &_msginfo, sizeof (_msginfo)) != sizeof (_msginfo)) {
+		glibtop_warn_io_r (server, "kvm_read (msginfo)");
+		return;
+	}
+
+	server->sysdeps.msg_limits = _glibtop_sysdeps_msg_limits;
 }
 
 /* Provides information about sysv ipc limits. */
@@ -72,6 +80,9 @@ glibtop_get_msg_limits_p (glibtop *server, glibtop_msg_limits *buf)
 	
 	memset (buf, 0, sizeof (glibtop_msg_limits));
 
+	if (server->sysdeps.msg_limits == 0)
+		return;
+
 	buf->msgmax = _msginfo.msgmax;
 	buf->msgmni = _msginfo.msgmni;
 	buf->msgmnb = _msginfo.msgmnb;
