@@ -1,4 +1,4 @@
-/* $Id: nosuid.c,v 1.1 1998/08/06 21:57:44 martin Exp $ */
+/* $Id: nosuid.c,v 1.3 1998/10/06 09:04:19 martin Exp $ */
 
 /* Copyright (C) 1995, 1996, 1997 Free Software Foundation, Inc.
    This file is part of the Gnome Top Library.
@@ -21,10 +21,13 @@
 
 #include <glibtop.h>
 #include <glibtop/open.h>
+#include <glibtop/close.h>
 
 void
-glibtop_open_s (glibtop *server, const char *program_name,
-		const unsigned long features, const unsigned flags)
+glibtop_open_s (glibtop *server,
+		const char *program_name,
+		const unsigned long features,
+		const unsigned flags)
 { }
 
 void
