@@ -1,4 +1,4 @@
-/* $Id: proclist.c,v 1.8 1998/08/24 19:55:27 martin Exp $ */
+/* $Id: proclist.c,v 1.10 1998/10/30 23:06:48 martin Exp $ */
 
 /* Copyright (C) 1995, 1996, 1997 Free Software Foundation, Inc.
    This file is part of the Gnome Top Library.
@@ -58,41 +58,44 @@ glibtop_init_proclist_p (glibtop *server)
 
 unsigned *
 glibtop_get_proclist_p (glibtop *server, glibtop_proclist *buf,
-			int64_t which, int64_t arg)
+			int64_t real_which, int64_t arg)
 {
 	struct kinfo_proc *pinfo;
 	unsigned *pids = NULL;
-	int count;
-	int i;
+	int which, count;
+	int i,j;
 
 	glibtop_init_p (server, (1 << GLIBTOP_SYSDEPS_PROCLIST), 0);
 	
 	memset (buf, 0, sizeof (glibtop_proclist));
 
-	glibtop_suid_enter (server);
-
-	which &= GLIBTOP_KERN_PROC_MASK;
+	which = (int)(real_which & GLIBTOP_KERN_PROC_MASK);
 
 	/* Get the process data */
 	pinfo = kvm_getprocs (server->machine.kd, which, arg, &count);
-	if ((pinfo == NULL) || (count < 1))
-		glibtop_error_io_r (server, "kvm_getprocs (proclist)");
-
-	glibtop_suid_leave (server);
-
+	if ((pinfo == NULL) || (count < 1)) {
+		glibtop_warn_io_r (server, "kvm_getprocs (proclist)");
+		return NULL;
+	}
 	count--;
 
 	/* Allocate count objects in the pids_chain array
 	 * Same as malloc is pids is NULL, which it is. */
 	pids = glibtop_realloc_r (server, pids, count * sizeof (unsigned));
 	/* Copy the pids over to this chain */
-	for (i=0; i < count; i++) {
-		pids [i] = (unsigned) pinfo[i].kp_proc.p_pid;
+	for (i=j=0; i < count; i++) {
+		if ((real_which & GLIBTOP_EXCLUDE_IDLE) &&
+		    (pinfo[i].kp_proc.p_stat != SRUN))
+			continue;
+		else if ((real_which & GLIBTOP_EXCLUDE_SYSTEM) &&
+			 (pinfo[i].kp_eproc.e_pcred.p_ruid == 0))
+			continue;
+		pids [j++] = (unsigned) pinfo[i].kp_proc.p_pid;
 	} /* end for */
 	/* Set the fields in buf */
-	buf->number = count;
+	buf->number = j;
 	buf->size = sizeof (unsigned);
-	buf->total = count * sizeof (unsigned);
+	buf->total = j * sizeof (unsigned);
 	buf->flags = _glibtop_sysdeps_proclist;
 	return pids;
 }
