@@ -1,4 +1,4 @@
-/* $Id: procstate.c,v 1.6 1998/08/24 19:55:32 martin Exp $ */
+/* $Id: procstate.c,v 1.10 1998/12/06 11:08:12 martin Exp $ */
 
 /* Copyright (C) 1995, 1996, 1997 Free Software Foundation, Inc.
    This file is part of the Gnome Top Library.
@@ -25,7 +25,9 @@
 
 #include <glibtop_suid.h>
 
+#ifndef __OpenBSD__
 #include <sys/user.h>
+#endif
 
 static const unsigned long _glibtop_sysdeps_proc_state =
 (1 << GLIBTOP_PROC_STATE_CMD) + (1 << GLIBTOP_PROC_STATE_STATE) +
@@ -53,14 +55,15 @@ glibtop_get_proc_state_p (glibtop *server,
 	
 	memset (buf, 0, sizeof (glibtop_proc_state));
 
-	glibtop_suid_enter (server);
-
+	/* It does not work for the swapper task. */
+	if (pid == 0) return;
+	
 	/* Get the process information */
 	pinfo = kvm_getprocs (server->machine.kd, KERN_PROC_PID, pid, &count);
-	if ((pinfo == NULL) || (count != 1))
-		glibtop_error_io_r (server, "kvm_getprocs (%d)", pid);
-
-	glibtop_suid_leave (server);
+	if ((pinfo == NULL) || (count != 1)) {
+		glibtop_warn_io_r (server, "kvm_getprocs (%d)", pid);
+		return;
+	}
 
 	strncpy (buf->cmd, pinfo [0].kp_proc.p_comm, sizeof (buf->cmd)-1);
 	buf->cmd [sizeof (buf->cmd)-1] = 0;
@@ -68,7 +71,26 @@ glibtop_get_proc_state_p (glibtop *server,
 	buf->uid = pinfo [0].kp_eproc.e_pcred.p_svuid;
 	buf->gid = pinfo [0].kp_eproc.e_pcred.p_svgid;
 
-	buf->state = pinfo [0].kp_proc.p_stat;
+	switch (pinfo [0].kp_proc.p_stat) {
+	case SIDL:
+		buf->state = 'I';
+		break;
+	case SRUN:
+		buf->state = 'R';
+		break;
+	case SSLEEP:
+		buf->state = 'S';
+		break;
+	case SSTOP:
+		buf->state = 'T';
+		break;
+	case SZOMB:
+		buf->state = 'Z';
+		break;
+	default:
+		buf->state = '?';
+		break;
+	}
 
 	/* Set the flags for the data we're about to return*/
 	buf->flags = _glibtop_sysdeps_proc_state;
