@@ -1,4 +1,4 @@
-/* $Id: procuid.c,v 1.5 1998/08/24 19:55:34 martin Exp $ */
+/* $Id: procuid.c,v 1.7 1998/11/11 15:58:22 martin Exp $ */
 
 /* Copyright (C) 1995, 1996, 1997 Free Software Foundation, Inc.
    This file is part of the Gnome Top Library.
@@ -53,14 +53,15 @@ glibtop_get_proc_uid_p (glibtop *server, glibtop_proc_uid *buf,
 	
 	memset (buf, 0, sizeof (glibtop_proc_uid));
 
-	glibtop_suid_enter (server);
-
+	/* It does not work for the swapper task. */
+	if (pid == 0) return;
+	
 	/* Get the process information */
 	pinfo = kvm_getprocs (server->machine.kd, KERN_PROC_PID, pid, &count);
-	if ((pinfo == NULL) || (count != 1))
-		glibtop_error_io_r (server, "kvm_getprocs (%d)", pid);
-
-	glibtop_suid_leave (server);
+	if ((pinfo == NULL) || (count != 1)) {
+		glibtop_warn_io_r (server, "kvm_getprocs (%d)", pid);
+		return;
+	}
 
 	buf->uid  = pinfo [0].kp_eproc.e_pcred.p_ruid;
 	buf->euid = pinfo [0].kp_eproc.e_pcred.p_svuid;
